Given $$ \frac{dy}{dx} = -y(x),\quad y(0)=1 $$ What is the solution of this equation? $y=e^{-y}$ $y=e^{y}$ Almost, but the sign is wrong (note the minus!). ~~~{.Python} from math import exp def f(x): return exp(x) ~~~ Ooops, forgot a minus: `exp(-x)`, otherwise this Python code must be considered as a good answer. It is more natural, though, to write the solution to the problem in mathematical notation: $$ y(x) = e^{-y}. $$ The solution cannot be found because there is a derivative in the equation. Equations with derivatives can be solved; they are termed *differential equations*. The equation is meaningless: an equation must be an equation for $x$ or $y$, not a function $y(x)$. Equations where the unknown is a function, as $y(x)$ here, are called *differential equations*, and are solved by special techniques. [Fundamental test:] What is the capital of Norway? [Answer 1:] Stockholm Stockholm is the capital of Sweden. [Answer 2:] London [Answer 3:] Oslo Bergen Those from Bergen would claim so, but nobody else.